@@ -42,6 +42,7 @@ from .cli.semantic_handlers import (
     handle_semantic_stats,
 )
 
+console = Console()
 app = typer.Typer(
     help="Crackerjack: Your Python project setup and style enforcement tool.",
 )
@@ -455,11 +456,18 @@ def _setup_debug_and_verbose_flags(
         ai_fix = True
         verbose = True
         options.verbose = True
+        options.ai_debug = True  # Set ai_debug on options for downstream checks
 
     if debug:
         verbose = True
         options.verbose = True
 
+    # Set up structured logging for AI-related operations if needed
+    if ai_fix or ai_debug:
+        from crackerjack.services.logging import setup_structured_logging
+
+        setup_structured_logging(level="DEBUG", json_output=True)
+
     return ai_fix, verbose
 
 
@@ -1227,6 +1235,7 @@ def main(
     fast_iteration: bool = CLI_OPTIONS["fast_iteration"],
     tool: str | None = CLI_OPTIONS["tool"],
     changed_only: bool = CLI_OPTIONS["changed_only"],
+    all_files: bool = CLI_OPTIONS["all_files"],
     create_pr: bool = CLI_OPTIONS["create_pr"],
     ai_fix: bool = CLI_OPTIONS["ai_fix"],
     start_mcp_server: bool = CLI_OPTIONS["start_mcp_server"],
@@ -1347,6 +1356,7 @@ def main(
         fast_iteration,
         tool,
         changed_only,
+        all_files,
         create_pr,
         async_mode,
         experimental_hooks,
