@@ -3,15 +3,32 @@ from pathlib import Path
 
 from ..services.regex_patterns import SAFE_PATTERNS
 from .base import (
+    AgentContext,
     FixResult,
     Issue,
     IssueType,
     SubAgent,
     agent_registry,
 )
+from .semantic_helpers import (
+    SemanticInsight,
+    create_semantic_enhancer,
+    get_session_enhanced_recommendations,
+)
 
 
 class DRYAgent(SubAgent):
+    """Agent for detecting and fixing DRY (Don't Repeat Yourself) violations.
+
+    Enhanced with semantic context to detect conceptual duplicates beyond
+    just syntactic pattern matching.
+    """
+
+    def __init__(self, context: AgentContext) -> None:
+        super().__init__(context)
+        self.semantic_enhancer = create_semantic_enhancer(context.project_path)
+        self.semantic_insights: dict[str, SemanticInsight] = {}
+
     def get_supported_types(self) -> set[IssueType]:
         return {IssueType.DRY_VIOLATION}
 
@@ -66,8 +83,13 @@ class DRYAgent(SubAgent):
                 remaining_issues=[f"Could not read file: {file_path}"],
             )
 
+        # Detect traditional pattern-based violations
         violations = self._detect_dry_violations(content, file_path)
 
+        # Enhance with semantic duplicate detection
+        semantic_violations = await self._detect_semantic_violations(content, file_path)
+        violations.extend(semantic_violations)
+
         if not violations:
             return FixResult(
                 success=True,
@@ -75,9 +97,9 @@ class DRYAgent(SubAgent):
                 recommendations=["No DRY violations detected"],
             )
 
-        return self._apply_and_save_dry_fixes(file_path, content, violations)
+        return await self._apply_and_save_dry_fixes(file_path, content, violations)
 
-    def _apply_and_save_dry_fixes(
+    async def _apply_and_save_dry_fixes(
         self,
         file_path: Path,
         content: str,
@@ -96,6 +118,28 @@ class DRYAgent(SubAgent):
                 remaining_issues=[f"Failed to write fixed file: {file_path}"],
             )
 
+        # Enhance recommendations with semantic insights and session continuity
+        recommendations = ["Verify functionality after DRY fixes"]
+        if hasattr(self, "current_semantic_insight") and self.current_semantic_insight:
+            recommendations = self.semantic_enhancer.enhance_recommendations(
+                recommendations, self.current_semantic_insight
+            )
+            # Log semantic context for debugging
+            summary = self.semantic_enhancer.get_semantic_context_summary(
+                self.current_semantic_insight
+            )
+            self.log(f"Semantic context: {summary}")
+
+            # Store insight for session continuity
+            await self.semantic_enhancer.store_insight_to_session(
+                self.current_semantic_insight, "DRYAgent"
+            )
+
+        # Enhance with session-stored insights
+        recommendations = await get_session_enhanced_recommendations(
+            recommendations, "DRYAgent", self.context.project_path
+        )
+
         return FixResult(
             success=True,
             confidence=0.8,
@@ -104,7 +148,7 @@ class DRYAgent(SubAgent):
                 "Consolidated repetitive patterns",
             ],
             files_modified=[str(file_path)],
-            recommendations=["Verify functionality after DRY fixes"],
+            recommendations=recommendations,
         )
 
     def _create_no_fixes_result(self) -> FixResult:
@@ -397,5 +441,145 @@ def _ensure_path(path: str | Path) -> Path:
 
         return modified
 
+    async def _detect_semantic_violations(
+        self, content: str, file_path: Path
+    ) -> list[dict[str, t.Any]]:
+        """Detect semantic code duplicates using vector similarity."""
+        violations = []
+
+        try:
+            # Extract key code functions for semantic analysis
+            code_elements = self._extract_code_functions(content)
+
+            for element in code_elements:
+                if element["type"] == "function" and len(element["body"]) > 50:
+                    # Search for semantically similar functions
+                    insight = await self.semantic_enhancer.find_duplicate_patterns(
+                        element["signature"]
+                        + "\n"
+                        + element["body"][:200],  # Include body sample
+                        current_file=file_path,
+                    )
+
+                    if insight.high_confidence_matches > 0:
+                        violations.append(
+                            {
+                                "type": "semantic_duplicate",
+                                "element": element,
+                                "similar_patterns": insight.related_patterns[
+                                    :3
+                                ],  # Top 3 matches
+                                "confidence_score": insight.high_confidence_matches
+                                / insight.total_matches
+                                if insight.total_matches > 0
+                                else 0,
+                                "suggestion": "Consider extracting common functionality to shared utility",
+                            }
+                        )
+
+                        # Store insight for recommendation enhancement
+                        self.current_semantic_insight = insight
+
+        except Exception as e:
+            self.log(f"Warning: Semantic violation detection failed: {e}")
+
+        return violations
+
+    def _extract_code_functions(self, content: str) -> list[dict[str, t.Any]]:
+        """Extract functions from code for semantic analysis."""
+        functions: list[dict[str, t.Any]] = []
+        lines = content.split("\n")
+        current_function = None
+
+        for i, line in enumerate(lines):
+            stripped = line.strip()
+
+            if self._should_skip_line(stripped, current_function, line):
+                continue
+
+            indent = len(line) - len(line.lstrip())
+
+            if self._is_function_definition(stripped):
+                current_function = self._handle_function_definition(
+                    functions, current_function, stripped, indent, i
+                )
+            elif current_function:
+                current_function = self._handle_function_body_line(
+                    functions, current_function, line, stripped, indent, i
+                )
+
+        # Add last function if exists
+        if current_function:
+            current_function["end_line"] = len(lines)
+            functions.append(current_function)
+
+        return functions
+
+    def _should_skip_line(
+        self, stripped: str, current_function: dict[str, t.Any] | None, line: str
+    ) -> bool:
+        """Check if line should be skipped during function extraction."""
+        if not stripped or stripped.startswith("#"):
+            if current_function:
+                current_function["body"] += line + "\n"
+            return True
+        return False
+
+    def _is_function_definition(self, stripped: str) -> bool:
+        """Check if line is a function definition."""
+        return stripped.startswith("def ") and "(" in stripped
+
+    def _handle_function_definition(
+        self,
+        functions: list[dict[str, t.Any]],
+        current_function: dict[str, t.Any] | None,
+        stripped: str,
+        indent: int,
+        line_index: int,
+    ) -> dict[str, t.Any]:
+        """Handle a new function definition."""
+        # Save previous function if exists
+        if current_function:
+            functions.append(current_function)
+
+        func_name = stripped.split("(")[0].replace("def ", "").strip()
+        return {
+            "type": "function",
+            "name": func_name,
+            "signature": stripped,
+            "start_line": line_index + 1,
+            "body": "",
+            "indent_level": indent,
+        }
+
+    def _handle_function_body_line(
+        self,
+        functions: list[dict[str, t.Any]],
+        current_function: dict[str, t.Any],
+        line: str,
+        stripped: str,
+        indent: int,
+        line_index: int,
+    ) -> dict[str, t.Any] | None:
+        """Handle a line within a function body."""
+        # Check if we're still inside the function
+        if self._is_line_inside_function(current_function, indent, stripped):
+            current_function["body"] += line + "\n"
+            return current_function
+        else:
+            # Function ended
+            current_function["end_line"] = line_index
+            functions.append(current_function)
+            return None
+
+    def _is_line_inside_function(
+        self, current_function: dict[str, t.Any], indent: int, stripped: str
+    ) -> bool:
+        """Check if line is still inside the current function."""
+        return indent > current_function["indent_level"] or (
+            indent == current_function["indent_level"]
+            and stripped.startswith(('"', "'", "@"))
+        )
+
 
 agent_registry.register(DRYAgent)
