@@ -3,7 +3,8 @@ import typing as t
 from dataclasses import dataclass
 from pathlib import Path
 
-from rich.console import Console
+from acb.console import Console
+from acb.depends import depends
 
 from .code_cleaner import CleaningResult, CodeCleaner, PackageCleaningResult
 from .core.workflow_orchestrator import WorkflowOrchestrator
@@ -49,16 +50,15 @@ class CrackerjackAPI:
         verbose: bool = False,
     ) -> None:
         self.project_path = project_path or Path.cwd()
-        self.console = console or Console()
+        self.console = console or depends.get_sync(Console)
         self.verbose = verbose
 
         self.orchestrator = WorkflowOrchestrator(
-            console=self.console,
             pkg_path=self.project_path,
             verbose=self.verbose,
         )
 
-        self.container = self.orchestrator.container
+        self.container = t.cast(t.Any, getattr(self.orchestrator, "container", None))
 
         self._code_cleaner: CodeCleaner | None = None
         self._interactive_cli: InteractiveCLI | None = None
@@ -600,7 +600,6 @@ class CrackerjackAPI:
         return None
 
     def _find_fallback_package_directory(self) -> Path | None:
-        # Only check project directory name, not src
         package_dir = self.project_path / self.project_path.name
         if self._is_valid_python_package_directory(package_dir):
             return package_dir
