@@ -44,7 +44,7 @@ class ServiceDescriptor:
     created_count: int = 0
     dependencies: list[type] = field(default_factory=list)
 
-    def __post_init__(self) -> None:
+    def __post_init__(self):
         if self.implementation is self.factory is self.instance is None:
             msg = "Must provide either implementation, factory, or instance"
             raise ValueError(msg)
@@ -146,7 +146,7 @@ class DependencyResolver:
 
     def _build_constructor_kwargs(self, implementation: type) -> dict[str, Any]:
         init_sig = inspect.signature(implementation.__init__)
-        kwargs: dict[str, Any] = {}
+        kwargs = {}
 
         for param_name, param in init_sig.parameters.items():
             if param_name == "self":
@@ -300,7 +300,7 @@ class EnhancedDependencyContainer:
         self._current_scope = scope
 
     def get_service_info(self) -> dict[str, Any]:
-        info: dict[str, Any] = {}
+        info = {}
 
         with self._lock:
             for key, descriptor in self._services.items():
@@ -391,7 +391,7 @@ class EnhancedDependencyContainer:
     def _get_service_key(self, interface: type) -> str:
         return f"{interface.__module__}.{interface.__name__}"
 
-    def __enter__(self) -> "EnhancedDependencyContainer":
+    def __enter__(self):
         return self
 
     def __exit__(
@@ -463,13 +463,11 @@ class ServiceCollectionBuilder:
 
         from crackerjack.managers.publish_manager import PublishManagerImpl
 
+        # Use factory without parameters to trigger @depends.inject decorator
+        # The decorator will inject all dependencies from the DI container
         self.container.register_transient(
             PublishManager,
-            factory=lambda: PublishManagerImpl(
-                console=console,
-                pkg_path=pkg_path,
-                dry_run=self.dry_run,
-            ),
+            factory=lambda: PublishManagerImpl(),
         )
 
         return self
