@@ -9,6 +9,14 @@ from acb.depends import Inject, depends
 from acb.logger import Logger
 from rich import box
 from rich.panel import Panel
+from rich.progress import (
+    BarColumn,
+    MofNCompleteColumn,
+    Progress,
+    SpinnerColumn,
+    TextColumn,
+    TimeElapsedColumn,
+)
 from rich.table import Table
 
 from crackerjack.code_cleaner import CodeCleaner
@@ -95,6 +103,7 @@ class PhaseCoordinator:
         self._filesystem_cache = filesystem_cache
 
         self._last_hook_summary: dict[str, t.Any] | None = None
+        self._last_hook_results: list[HookResult] = []
 
         self._lazy_autofix = create_lazy_service(
             lambda: AutofixCoordinator(pkg_path=pkg_path),
@@ -102,6 +111,9 @@ class PhaseCoordinator:
         )
         self.console.print()
 
+        # Track if fast hooks have already started in this session to prevent duplicates
+        self._fast_hooks_started: bool = False
+
     # --- Output/formatting helpers -------------------------------------------------
     @staticmethod
     def _strip_ansi(text: str) -> str:
@@ -166,15 +178,49 @@ class PhaseCoordinator:
             self.console.print("[yellow]⚠️[/yellow] Skipping fast hooks (--skip-hooks).")
             return True
 
-        self.session.track_task("hooks_fast", "Fast quality checks")
-        self._display_hook_phase_header(
-            "FAST HOOKS",
-            "Formatters, import sorting, and quick static analysis",
-        )
+        # Prevent multiple fast-hook runs in a single workflow session unless
+        # explicitly reset by post-cleaning sanity check.
+        if getattr(self, "_fast_hooks_started", False):
+            self.logger.debug("Duplicate fast hooks invocation detected; skipping")
+            return True
 
-        success = self._execute_hooks_with_retry(
-            "fast", self.hook_manager.run_fast_hooks, options
-        )
+        # Mark fast hooks as started immediately to prevent duplicate calls in case of failures
+        self._fast_hooks_started = True
+        self.session.track_task("hooks_fast", "Fast quality checks")
+
+        # Fast hooks get 2 attempts (auto-fix on failure), comprehensive hooks run once
+        max_attempts = 2
+        attempt = 0
+
+        while attempt < max_attempts:
+            attempt += 1
+
+            # Display stage header for each attempt
+            if attempt > 1:
+                self.console.print(
+                    f"\n[yellow]♻️[/yellow]  Verification Retry {attempt}/{max_attempts}\n"
+                )
+
+            self._display_hook_phase_header(
+                "FAST HOOKS",
+                "Formatters, import sorting, and quick static analysis",
+            )
+
+            # Run hooks (now configured to run in fix mode by default)
+            success = self._execute_hooks_once(
+                "fast", self.hook_manager.run_fast_hooks, options, attempt
+            )
+
+            if success:
+                break
+
+            # Fast iteration mode intentionally avoids retries
+            if getattr(options, "fast_iteration", False):
+                break
+
+            # If we have more attempts, continue to retry to verify fixes worked
+            if attempt < max_attempts:
+                self._display_hook_failures("fast", self._last_hook_results, options)
 
         summary = self._last_hook_summary or {}
         details = self._format_hook_summary(summary)
@@ -202,12 +248,19 @@ class PhaseCoordinator:
             "Type, security, and complexity checking",
         )
 
-        success = self._execute_hooks_with_retry(
+        # Comprehensive hooks run once (no retry)
+        success = self._execute_hooks_once(
             "comprehensive",
             self.hook_manager.run_comprehensive_hooks,
             options,
+            attempt=1,
         )
 
+        if not success:
+            self._display_hook_failures(
+                "comprehensive", self._last_hook_results, options
+            )
+
         summary = self._last_hook_summary or {}
         details = self._format_hook_summary(summary)
 
@@ -259,6 +312,16 @@ class PhaseCoordinator:
         if not options.commit:
             return True
 
+        # Skip if publishing phase already handled commits
+        # (Publishing phase handles both pre-publish and version-bump commits when -c is used)
+        version_type = self._determine_version_type(options)
+        if version_type:
+            # Publishing workflow already committed everything
+            self.console.print(
+                "[dim]ℹ️ Commit phase skipped (handled by publish workflow)[/dim]"
+            )
+            return True
+
         # Display commit & push header
         self._display_commit_push_header()
         self.session.track_task("commit", "Git commit and push")
@@ -268,58 +331,98 @@ class PhaseCoordinator:
         commit_message = self._get_commit_message(changed_files, options)
         return self._execute_commit_and_push(changed_files, commit_message)
 
-    def _execute_hooks_with_retry(
+    def _execute_hooks_once(
         self,
         suite_name: str,
         hook_runner: t.Callable[[], list[HookResult]],
         options: OptionsProtocol,
+        attempt: int,
     ) -> bool:
-        """Execute a hook suite with lightweight retry handling."""
-        attempt = 0
-        # Only fast hooks should retry on failure; comprehensive hooks run once
-        max_attempts = 2 if suite_name == "fast" else 1
+        """Execute a hook suite once with progress bar (no retry logic - retry is handled at stage level)."""
         self._last_hook_summary = None
+        self._last_hook_results = []
 
-        while attempt < max_attempts:
-            attempt += 1
-            try:
+        # Get hook count before creating progress bar so we can show total upfront
+        hook_count = self.hook_manager.get_hook_count(suite_name)
+
+        # Create compact progress bar for 70-char width
+        # Format: ⠋ Running hooks... ━━━━━╸━━━ 7/11 0:00:32
+        progress = Progress(
+            SpinnerColumn(spinner_name="dots"),
+            TextColumn("[cyan]{task.description}"),
+            BarColumn(bar_width=20),  # Fixed width to prevent console overflow
+            MofNCompleteColumn(),
+            TimeElapsedColumn(),
+            console=self.console,  # Uses console width (70 chars)
+            transient=True,  # Remove after completion
+        )
+
+        # Progress callback for hook manager to call
+        task_id = None
+
+        # Maintain separate counters for started/completed if needed in the future
+        def update_progress(completed: int, total: int) -> None:
+            nonlocal task_id
+            if task_id is None:
+                return
+            # Update only completed count (total is already set during initialization)
+            progress.update(task_id, completed=completed)
+
+        def update_progress_started(started: int, total: int) -> None:
+            nonlocal task_id
+            if task_id is None:
+                return
+            # Tick progress bar when a hook starts
+            progress.update(task_id, completed=started)
+
+        # Store callback in hook_manager temporarily
+        original_callback = getattr(self.hook_manager, "_progress_callback", None)
+        original_start_callback = getattr(
+            self.hook_manager, "_progress_start_callback", None
+        )
+        self.hook_manager._progress_callback = update_progress
+        self.hook_manager._progress_start_callback = update_progress_started
+
+        try:
+            with progress:
+                # Create task with known total
+                task_id = progress.add_task(
+                    f"Running {suite_name} hooks...",
+                    total=hook_count,
+                )
+
+                # Execute hooks - the hook_manager will call update_progress via callback
                 hook_results = hook_runner() or []
-            except Exception as exc:
-                self.console.print(
-                    f"[red]❌[/red] {suite_name.title()} hooks encountered an unexpected error: {exc}"
-                )
-                self.logger.exception(
-                    "Hook execution raised exception",
-                    extra={"suite": suite_name, "attempt": attempt},
-                )
-                return False
+                self._last_hook_results = hook_results
 
-            summary = self.hook_manager.get_hook_summary(hook_results)
-            self._last_hook_summary = summary
-            self._report_hook_results(suite_name, hook_results, summary, attempt)
+        except Exception as exc:
+            self.console.print(
+                f"[red]❌[/red] {suite_name.title()} hooks encountered an unexpected error: {exc}"
+            )
+            self.logger.exception(
+                "Hook execution raised exception",
+                extra={"suite": suite_name, "attempt": attempt},
+            )
+            return False
+        finally:
+            # Restore original callback
+            self.hook_manager._progress_callback = original_callback
+            self.hook_manager._progress_start_callback = original_start_callback
 
-            if summary.get("failed", 0) == 0 and summary.get("errors", 0) == 0:
-                return True
+        summary = self.hook_manager.get_hook_summary(hook_results)
+        self._last_hook_summary = summary
+        self._report_hook_results(suite_name, hook_results, summary, attempt)
 
-            self._display_hook_failures(suite_name, hook_results)
-
-            # Fast iteration mode intentionally avoids retries
-            if getattr(options, "fast_iteration", False):
-                break
-
-            # If we have more attempts, the loop will continue and retry
+        if summary.get("failed", 0) == 0 and summary.get("errors", 0) == 0:
+            return True
 
         self.logger.warning(
             "Hook suite reported failures",
             extra={
                 "suite": suite_name,
-                "attempts": attempt,
-                "failed": self._last_hook_summary.get("failed", 0)
-                if self._last_hook_summary
-                else None,
-                "errors": self._last_hook_summary.get("errors", 0)
-                if self._last_hook_summary
-                else None,
+                "attempt": attempt,
+                "failed": summary.get("failed", 0),
+                "errors": summary.get("errors", 0),
             },
         )
         return False
@@ -330,8 +433,8 @@ class PhaseCoordinator:
         # Combine title and description into a single line with leading icon
         pretty_title = title.title()
         message = (
-            f"[bold bright_cyan]🔍[/bold bright_cyan] "
-            f"[bold bright_white]{pretty_title} - {description}[/bold bright_white]"
+            f"[bold bright_cyan]🔍 {pretty_title}[/bold bright_cyan][bold bright_white]"
+            f" - {description}[/bold bright_white]"
         )
         self.console.print(message)
         self.console.print(sep + "\n")
@@ -364,6 +467,8 @@ class PhaseCoordinator:
             self.console.print(
                 f"\n[red]❌[/red] {base_message} ({failed} failed, {errors} errors).\n"
             )
+            # Always show a results table to aid debugging when there are failures
+            self._render_hook_results_table(suite_name, results)
         else:
             self.console.print(f"\n[green]✅[/green] {base_message}.\n")
             self._render_hook_results_table(suite_name, results)
@@ -420,7 +525,12 @@ class PhaseCoordinator:
         self,
         suite_name: str,
         results: list[HookResult],
+        options: OptionsProtocol,
     ) -> None:
+        # Show detailed failures if --verbose or --ai-debug flag is set
+        if not (options.verbose or getattr(options, "ai_debug", False)):
+            return
+
         failing = [
             result
             for result in results
@@ -490,38 +600,108 @@ class PhaseCoordinator:
     def _execute_publishing_workflow(
         self, options: OptionsProtocol, version_type: str
     ) -> bool:
+        # ========================================
+        # STAGE 0: PRE-PUBLISH COMMIT (if -c flag)
+        # ========================================
+        # If user specified --commit, commit any existing changes BEFORE version bump
+        if options.commit:
+            existing_changes = self.git_service.get_changed_files()
+            if existing_changes:
+                self._display_commit_push_header()
+                self.console.print(
+                    "[cyan]ℹ️[/cyan] Committing existing changes before version bump..."
+                )
+                commit_message = self._get_commit_message(existing_changes, options)
+                if not self._execute_commit_and_push(existing_changes, commit_message):
+                    self.session.fail_task(
+                        "publishing", "Failed to commit pre-publish changes"
+                    )
+                    return False
+                self.console.print(
+                    "[green]✅[/green] Pre-publish changes committed and pushed\n"
+                )
+
+        # ========================================
+        # STAGE 1: VERSION BUMP
+        # ========================================
+        self._display_version_bump_header()
+
         new_version = self.publish_manager.bump_version(version_type)
         if not new_version:
             self.session.fail_task("publishing", "Version bumping failed")
             return False
 
-        self.console.print(f"Version bumped to {new_version}")
+        self.console.print(f"[green]✅[/green] Version bumped to {new_version}")
+        self.console.print(
+            f"[green]✅[/green] Changelog updated for version {new_version}"
+        )
 
-        # Stage files before publishing
-        if not self.git_service.add_all_files():
-            self.console.print(
-                "[yellow]⚠️ Failed to stage files, continuing...[/yellow]"
-            )
+        # ========================================
+        # STAGE 2: COMMIT, TAG & PUSH
+        # ========================================
+        self._display_commit_push_header()
 
+        # Stage changes
+        changed_files = self.git_service.get_changed_files()
+        if not changed_files:
+            self.console.print("[yellow]⚠️[/yellow] No changes to stage")
+            self.session.fail_task("publishing", "No changes to commit")
+            return False
+
+        if not self.git_service.add_files(changed_files):
+            self.session.fail_task("publishing", "Failed to stage files")
+            return False
+        self.console.print(f"[green]✅[/green] Staged {len(changed_files)} files")
+
+        # Commit
+        commit_message = f"chore: bump version to {new_version}"
+        if not self.git_service.commit(commit_message):
+            self.session.fail_task("publishing", "Failed to commit changes")
+            return False
+
+        # Create git tag locally (before push, so both commit and tag go together)
+        if not options.no_git_tags:
+            if not self.publish_manager.create_git_tag_local(new_version):
+                self.console.print(
+                    f"[yellow]⚠️[/yellow] Failed to create git tag v{new_version}"
+                )
+
+        # Push commit and tag together in single operation
+        if not self.git_service.push_with_tags():
+            self.console.print("[yellow]⚠️[/yellow] Push failed. Please push manually.")
+            # Not failing the whole workflow for a push failure
+
+        # ========================================
+        # STAGE 3: PUBLISH TO PYPI
+        # ========================================
+        self._display_publish_header()
+
+        # Build and publish package
         if not self.publish_manager.publish_package():
             self.session.fail_task("publishing", "Package publishing failed")
             return False
 
-        if not options.no_git_tags:
-            if not self.publish_manager.create_git_tag(new_version):
-                self.console.print(
-                    f"[yellow]⚠️ Failed to create git tag {new_version}[/yellow]"
-                )
-
         self.session.complete_task("publishing", f"Published version {new_version}")
         return True
 
+    def _display_version_bump_header(self) -> None:
+        sep = make_separator("-")
+        self.console.print("\n" + sep)
+        self.console.print("[bold bright_cyan]📝 VERSION BUMP[/bold bright_cyan]")
+        self.console.print(sep + "\n")
+
     def _display_commit_push_header(self) -> None:
         sep = make_separator("-")
         self.console.print("\n" + sep)
         self.console.print("[bold bright_blue]📦 COMMIT & PUSH[/bold bright_blue]")
         self.console.print(sep + "\n")
 
+    def _display_publish_header(self) -> None:
+        sep = make_separator("-")
+        self.console.print("\n" + sep)
+        self.console.print("[bold bright_green]🚀 PUBLISH TO PYPI[/bold bright_green]")
+        self.console.print(sep + "\n")
+
     def _handle_no_changes_to_commit(self) -> bool:
         self.console.print("No changes to commit.")
         self.session.complete_task("commit", "No changes to commit")
@@ -569,7 +749,7 @@ class PhaseCoordinator:
             self.session.fail_task("commit", "Failed to commit files")
             return False
         if not self.git_service.push():
-            self.console.print("[yellow]⚠️ Push failed. Please push manually.[/yellow]")
+            self.console.print("[yellow]⚠️[/yellow] Push failed. Please push manually.")
             # Not failing the whole workflow for a push failure
         self.session.complete_task("commit", "Committed and pushed changes")
         return True
