@@ -8,10 +8,11 @@ from datetime import datetime
 from pathlib import Path
 
 import yaml
-from rich.console import Console
+from acb import console as acb_console
+from acb.console import Console
 
 from crackerjack.agents.coordinator import AgentCoordinator
-from crackerjack.services.cache import CrackerjackCache
+from crackerjack.services.acb_cache_adapter import CrackerjackCache
 
 logger = logging.getLogger(__name__)
 
@@ -60,7 +61,7 @@ class DualOutputGenerator:
         cache: CrackerjackCache | None = None,
     ):
         self.project_path = project_path or Path.cwd()
-        self.console = console or Console()
+        self.console = console or acb_console
         self.cache = cache or CrackerjackCache()
 
         # Documentation paths
