@@ -3,7 +3,7 @@ import time
 import typing as t
 from pathlib import Path
 
-from rich.console import Console
+from acb.console import Console
 
 from crackerjack.config.hooks import HookDefinition, HookStrategy
 from crackerjack.models.task import HookResult
@@ -261,11 +261,11 @@ class SmartCacheManager:
         hook_name: str,
         project_state: dict[str, t.Any],
     ) -> bool:
-        external_hooks = {"detect-secrets"}
+        external_hooks = set()
         if hook_name in external_hooks:
             return False
 
-        expensive_hooks = {"pyright", "bandit", "vulture", "complexipy"}
+        expensive_hooks = {"pyright", "bandit", "vulture", "complexipy", "gitleaks"}
         if hook_name in expensive_hooks:
             return True
 
