@@ -9,6 +9,7 @@ from crackerjack.config import CrackerjackSettings
 from crackerjack.config.hooks import HookConfigLoader
 from crackerjack.executors.hook_executor import HookExecutor
 from crackerjack.executors.lsp_aware_hook_executor import LSPAwareHookExecutor
+from crackerjack.executors.progress_hook_executor import ProgressHookExecutor
 from crackerjack.models.task import HookResult
 
 if t.TYPE_CHECKING:
@@ -21,6 +22,7 @@ class HookManagerImpl:
         pkg_path: Path,
         verbose: bool = False,
         quiet: bool = False,
+        debug: bool = False,
         enable_lsp_optimization: bool = False,
         enable_tool_proxy: bool = True,
         # Legacy parameters kept for backward compatibility (deprecated)
@@ -32,19 +34,28 @@ class HookManagerImpl:
     ) -> None:
         self.pkg_path = pkg_path
         self.executor: HookExecutor
+        self.debug = debug
 
         # Use LSP-aware executor if optimization is enabled
         if enable_lsp_optimization:
             console = depends.get_sync(Console)
             self.console = console  # Store console for later use
             self.executor = LSPAwareHookExecutor(
-                console, pkg_path, verbose, quiet, use_tool_proxy=enable_tool_proxy
+                console,
+                pkg_path,
+                verbose,
+                quiet,
+                debug,
+                use_tool_proxy=enable_tool_proxy,
             )
         else:
             # Create a console for the executor
             console = depends.get_sync(Console)
             self.console = console  # Store console for later use
-            self.executor = HookExecutor(console, pkg_path, verbose, quiet)
+            # Use ProgressHookExecutor with inline hook status (no progress bar)
+            self.executor = ProgressHookExecutor(
+                console, pkg_path, verbose, quiet, show_progress=False, debug=debug
+            )
 
         self.config_loader = HookConfigLoader()
         self._config_path: Path | None = None
@@ -95,11 +106,11 @@ class HookManagerImpl:
                     enable_caching=enable_caching,
                     cache_backend=cache_backend,
                 )
-                # Use constructor params or fall back to DI settings, then to hardcoded defaults
+                # Default to disabled unless explicitly enabled or project config exists
                 self.orchestration_enabled = (
-                    enable_orchestration
+                    bool(enable_orchestration)
                     if enable_orchestration is not None
-                    else self._settings.enable_orchestration
+                    else False
                 )
                 self.orchestration_mode = (
                     orchestration_mode
@@ -159,7 +170,14 @@ class HookManagerImpl:
             for hook in strategy.hooks:
                 hook.config_path = self._config_path
 
-        return await self._orchestrator.execute_strategy(strategy)
+        # Check for progress callback from PhaseCoordinator
+        getattr(self, "_progress_callback", None)
+
+        return await self._orchestrator.execute_strategy(
+            strategy,
+            progress_callback=getattr(self, "_progress_callback", None),
+            progress_start_callback=getattr(self, "_progress_start_callback", None),
+        )
 
     async def _run_comprehensive_hooks_orchestrated(self) -> list[HookResult]:
         """Run comprehensive hooks using orchestrator (async path)."""
@@ -172,7 +190,14 @@ class HookManagerImpl:
             for hook in strategy.hooks:
                 hook.config_path = self._config_path
 
-        return await self._orchestrator.execute_strategy(strategy)
+        # Check for progress callback from PhaseCoordinator
+        getattr(self, "_progress_callback", None)
+
+        return await self._orchestrator.execute_strategy(
+            strategy,
+            progress_callback=getattr(self, "_progress_callback", None),
+            progress_start_callback=getattr(self, "_progress_start_callback", None),
+        )
 
     def run_fast_hooks(self) -> list[HookResult]:
         # Use orchestrator if enabled (Phase 3+)
@@ -185,19 +210,12 @@ class HookManagerImpl:
                 # We're in an event loop, run in thread
                 import concurrent.futures
 
-                # Suppress executor printing while running in a background thread
-                prev_quiet = getattr(self.executor, "quiet", False)
-                with suppress(Exception):
-                    self.executor.quiet = True  # type: ignore[attr-defined]
-                try:
-                    with concurrent.futures.ThreadPoolExecutor() as executor:
-                        future = executor.submit(
-                            asyncio.run, self._run_fast_hooks_orchestrated()
-                        )
-                        return future.result()
-                finally:
-                    with suppress(Exception):
-                        self.executor.quiet = prev_quiet  # type: ignore[attr-defined]
+                # Let executor show progress - orchestrator doesn't display progress
+                with concurrent.futures.ThreadPoolExecutor() as executor:
+                    future = executor.submit(
+                        asyncio.run, self._run_fast_hooks_orchestrated()
+                    )
+                    return future.result()
             except RuntimeError:
                 # No event loop running, safe to use asyncio.run()
                 return asyncio.run(self._run_fast_hooks_orchestrated())
@@ -208,6 +226,13 @@ class HookManagerImpl:
         if self._config_path:
             for hook in strategy.hooks:
                 hook.config_path = self._config_path
+        # Wire progress callbacks for legacy executor path so ticks update
+        with suppress(Exception):
+            self.executor.set_progress_callbacks(
+                started_cb=getattr(self, "_progress_start_callback", None),
+                completed_cb=getattr(self, "_progress_callback", None),
+                total=len(strategy.hooks),
+            )
         execution_result = self.executor.execute_strategy(strategy)
         return execution_result.results
 
@@ -222,19 +247,12 @@ class HookManagerImpl:
                 # We're in an event loop, run in thread
                 import concurrent.futures
 
-                # Suppress executor printing while running in a background thread
-                prev_quiet = getattr(self.executor, "quiet", False)
-                with suppress(Exception):
-                    self.executor.quiet = True  # type: ignore[attr-defined]
-                try:
-                    with concurrent.futures.ThreadPoolExecutor() as executor:
-                        future = executor.submit(
-                            asyncio.run, self._run_comprehensive_hooks_orchestrated()
-                        )
-                        return future.result()
-                finally:
-                    with suppress(Exception):
-                        self.executor.quiet = prev_quiet  # type: ignore[attr-defined]
+                # Let executor show progress - orchestrator doesn't display progress
+                with concurrent.futures.ThreadPoolExecutor() as executor:
+                    future = executor.submit(
+                        asyncio.run, self._run_comprehensive_hooks_orchestrated()
+                    )
+                    return future.result()
             except RuntimeError:
                 # No event loop running, safe to use asyncio.run()
                 return asyncio.run(self._run_comprehensive_hooks_orchestrated())
@@ -245,6 +263,13 @@ class HookManagerImpl:
         if self._config_path:
             for hook in strategy.hooks:
                 hook.config_path = self._config_path
+        # Wire progress callbacks for legacy executor path so ticks update
+        with suppress(Exception):
+            self.executor.set_progress_callbacks(
+                started_cb=getattr(self, "_progress_start_callback", None),
+                completed_cb=getattr(self, "_progress_callback", None),
+                total=len(strategy.hooks),
+            )
         execution_result = self.executor.execute_strategy(strategy)
         return execution_result.results
 
@@ -391,6 +416,18 @@ class HookManagerImpl:
         all_hooks = fast_strategy.hooks + comprehensive_strategy.hooks
         return [hook.name for hook in all_hooks]
 
+    def get_hook_count(self, suite_name: str) -> int:
+        """Get the number of hooks in a specific suite.
+
+        Args:
+            suite_name: Name of the suite ('fast' or 'comprehensive')
+
+        Returns:
+            Number of hooks in the suite
+        """
+        strategy = self.config_loader.load_strategy(suite_name)
+        return len(strategy.hooks)
+
     def install_hooks(self) -> bool:
         """Install git hooks.
 
