@@ -14,6 +14,7 @@ from crackerjack.models.protocols import (
     SecurityServiceProtocol,
     VersionAnalyzerProtocol,
 )
+from crackerjack.utils.retry_utils import retry_api_call
 
 
 class PublishManagerImpl:
@@ -407,7 +408,7 @@ class PublishManagerImpl:
 
         try:
             self.console.print("[yellow]🚀[/ yellow] Publishing to PyPI...")
-            return self._perform_publish_workflow()
+            return self._perform_publish_workflow_with_retry()
         except Exception as e:
             self.console.print(f"[red]❌[/ red] Publish error: {e}")
             return False
@@ -424,6 +425,17 @@ class PublishManagerImpl:
 
         return self._execute_publish()
 
+    @retry_api_call(max_attempts=3, delay=2.0, backoff=2.0, max_delay=60.0)
+    def _perform_publish_workflow_with_retry(self) -> bool:
+        """Perform the publish workflow with retry logic for API connection errors."""
+        if self.dry_run:
+            return self._handle_dry_run_publish()
+
+        if not self.build_package():
+            return False
+
+        return self._execute_publish()
+
     def _handle_dry_run_publish(self) -> bool:
         self.console.print("[yellow]🔍[/ yellow] Would publish package to PyPI")
         return True
@@ -517,7 +529,28 @@ class PublishManagerImpl:
             self.console.print(f"[red]❌[/ red] Cleanup error: {e}")
             return False
 
+    def create_git_tag_local(self, version: str) -> bool:
+        """Create git tag locally without pushing (for use with push_with_tags)."""
+        try:
+            if self.dry_run:
+                self.console.print(
+                    f"[yellow]🔍[/ yellow] Would create git tag: v{version}",
+                )
+                return True
+            result = self._run_command(["git", "tag", f"v{version}"])
+            if result.returncode == 0:
+                self.console.print(f"[green]🏷️[/ green] Created git tag: v{version}")
+                return True
+            self.console.print(
+                f"[red]❌[/ red] Failed to create tag: {result.stderr}",
+            )
+            return False
+        except Exception as e:
+            self.console.print(f"[red]❌[/ red] Tag creation error: {e}")
+            return False
+
     def create_git_tag(self, version: str) -> bool:
+        """Create git tag and push it immediately (legacy method for standalone use)."""
         try:
             if self.dry_run:
                 self.console.print(
