@@ -1,3 +1,4 @@
+import re
 import subprocess
 import time
 import typing as t
@@ -6,9 +7,13 @@ from pathlib import Path
 from acb.config import root_path
 from acb.console import Console
 from acb.depends import Inject, depends
+from crackerjack.config import get_console_width
 from crackerjack.models.protocols import CoverageBadgeServiceProtocol, CoverageRatchetProtocol, OptionsProtocol, TestManagerProtocol, ServiceProtocol
 from crackerjack.services.coverage_badge_service import CoverageBadgeService
 from crackerjack.services.lsp_client import LSPClient
+from rich import box
+from rich.panel import Panel
+from rich.table import Table
 
 from .test_command_builder import TestCommandBuilder
 from .test_executor import TestExecutor
@@ -21,6 +26,7 @@ class TestManager:
         console: Inject[Console],
         coverage_ratchet: Inject[CoverageRatchetProtocol],
         coverage_badge: Inject[CoverageBadgeServiceProtocol],
+        command_builder: Inject[TestCommandBuilder],
         lsp_client: Inject[LSPClient] | None = None,
     ) -> None:
         self.console = console
@@ -34,7 +40,7 @@ class TestManager:
 
         # Ensure downstream components receive a concrete pathlib.Path
         self.executor = TestExecutor(console, self.pkg_path)
-        self.command_builder = TestCommandBuilder(self.pkg_path)
+        self.command_builder = command_builder
 
         # Services injected via ACB DI
         self.coverage_ratchet = coverage_ratchet
@@ -56,56 +62,73 @@ class TestManager:
         self.coverage_ratchet_enabled = enabled
         if enabled:
             self.console.print(
-                "[cyan]📊[/ cyan] Coverage ratchet enabled-targeting 100 % coverage"
+                "[cyan]📊[/cyan] Coverage ratchet enabled-targeting 100 % coverage"
             )
         else:
-            self.console.print("[yellow]⚠️[/ yellow] Coverage ratchet disabled")
+            self.console.print("[yellow]⚠️[/yellow] Coverage ratchet disabled")
 
     def run_tests(self, options: OptionsProtocol) -> bool:
+        # Early return if tests are disabled
+        if hasattr(options, "test") and not options.test:
+            return True
+
         start_time = time.time()
 
         try:
             result = self._execute_test_workflow(options)
             duration = time.time() - start_time
 
-            if result:
-                return self._handle_test_success(result.stdout, duration)
+            # Get worker count for statistics panel (don't print info messages)
+            workers = self.command_builder.get_optimal_workers(options, print_info=False)
+
+            if result.returncode == 0:
+                return self._handle_test_success(result.stdout, duration, options, workers)
             else:
                 return self._handle_test_failure(
-                    result.stderr if result else "", duration
+                    result.stderr if result else "",
+                    result.stdout if result else "",
+                    duration,
+                    options,
+                    workers,
                 )
 
         except Exception as e:
             return self._handle_test_error(start_time, e)
 
     def run_specific_tests(self, test_pattern: str) -> bool:
-        self.console.print(f"[cyan]🧪[/ cyan] Running tests matching: {test_pattern}")
+        self.console.print(f"[cyan]🧪[/cyan] Running tests matching: {test_pattern}")
 
         cmd = self.command_builder.build_specific_test_command(test_pattern)
         result = self.executor.execute_with_progress(cmd)
 
         success = result.returncode == 0
         if success:
-            self.console.print("[green]✅[/ green] Specific tests passed")
+            self.console.print("[green]✅[/green] Specific tests passed")
         else:
-            self.console.print("[red]❌[/ red] Some specific tests failed")
+            self.console.print("[red]❌[/red] Some specific tests failed")
 
         return success
 
     def validate_test_environment(self) -> bool:
         if not self.has_tests():
-            self.console.print("[yellow]⚠️[/ yellow] No tests found")
+            self.console.print("[yellow]⚠️[/yellow] No tests found")
             return False
 
+        from rich.spinner import Spinner
+        from rich.live import Live
+
         cmd = self.command_builder.build_validation_command()
-        result = subprocess.run(cmd, cwd=self.pkg_path, capture_output=True, text=True)
+
+        spinner = Spinner("dots", text="[cyan]Validating test environment...[/cyan]")
+        with Live(spinner, console=self.console, transient=True):
+            result = subprocess.run(cmd, cwd=self.pkg_path, capture_output=True, text=True)
 
         if result.returncode != 0:
-            self.console.print("[red]❌[/ red] Test environment validation failed")
+            self.console.print("[red]❌[/red] Test environment validation failed")
             self.console.print(result.stderr)
             return False
 
-        self.console.print("[green]✅[/ green] Test environment validated")
+        self.console.print("[green]✅[/green] Test environment validated")
         return True
 
     def get_coverage_ratchet_status(self) -> dict[str, t.Any]:
@@ -265,34 +288,234 @@ class TestManager:
         return self.executor.execute_with_progress(cmd, self._get_timeout(options))
 
     def _print_test_start_message(self, options: OptionsProtocol) -> None:
-        workers = self.command_builder.get_optimal_workers(options)
+        workers = self.command_builder.get_optimal_workers(options, print_info=False)
         timeout = self.command_builder.get_test_timeout(options)
 
         self.console.print(
-            f"[cyan]🧪[/ cyan] Running tests (workers: {workers}, timeout: {timeout}s)"
+            f"[cyan]🧪[/cyan] Running tests (workers: {workers}, timeout: {timeout}s)"
         )
 
-    def _handle_test_success(self, output: str, duration: float) -> bool:
-        self.console.print(f"[green]✅[/ green] Tests passed in {duration: .1f}s")
+    def _handle_test_success(
+        self,
+        output: str,
+        duration: float,
+        options: OptionsProtocol,
+        workers: int | str,
+    ) -> bool:
+        self.console.print(f"[green]✅[/green] Tests passed in {duration: .1f}s")
+
+        # Parse and display test statistics panel
+        stats = self._parse_test_statistics(output)
+        if stats["total"] > 0:  # Only show panel if tests were actually run
+            self._render_test_results_panel(stats, workers, success=True)
 
         if self.coverage_ratchet_enabled:
             return self._process_coverage_ratchet()
 
         return True
 
-    def _handle_test_failure(self, output: str, duration: float) -> bool:
-        self.console.print(f"[red]❌[/ red] Tests failed in {duration: .1f}s")
+    def _handle_test_failure(
+        self,
+        stderr: str,
+        stdout: str,
+        duration: float,
+        options: OptionsProtocol,
+        workers: int | str,
+    ) -> bool:
+        self.console.print(f"[red]❌[/red] Tests failed in {duration: .1f}s")
+
+        # Parse and display test statistics panel (use stdout for stats)
+        combined_output = stdout + "\n" + stderr
+        stats = self._parse_test_statistics(combined_output)
+        if stats["total"] > 0:  # Only show panel if tests were actually run
+            self._render_test_results_panel(stats, workers, success=False)
+
+        # Extract and display failures if --verbose or --ai-debug is enabled
+        if options.verbose or getattr(options, "ai_debug", False):
+            self._last_test_failures = self._extract_failure_lines(combined_output)
+            if combined_output.strip():
+                self.console.print("\n[red]Test Output:[/red]")
+                self.console.print(combined_output)
+        else:
+            self._last_test_failures = []
 
-        self._last_test_failures = self._extract_failure_lines(output)
         return False
 
     def _handle_test_error(self, start_time: float, error: Exception) -> bool:
         duration = time.time() - start_time
         self.console.print(
-            f"[red]💥[/ red] Test execution error after {duration: .1f}s: {error}"
+            f"[red]💥[/red] Test execution error after {duration: .1f}s: {error}"
         )
         return False
 
+    def _parse_test_statistics(self, output: str) -> dict[str, t.Any]:
+        """Parse test statistics from pytest output.
+
+        Extracts metrics like passed, failed, skipped, errors, and duration
+        from pytest's summary line.
+
+        Args:
+            output: Raw pytest output text
+
+        Returns:
+            Dictionary containing test statistics
+        """
+        stats = {
+            "total": 0,
+            "passed": 0,
+            "failed": 0,
+            "skipped": 0,
+            "errors": 0,
+            "xfailed": 0,
+            "xpassed": 0,
+            "duration": 0.0,
+            "coverage": None,
+        }
+
+        try:
+            # Parse pytest summary line (e.g., "5 passed, 2 failed, 1 skipped in 12.34s")
+            # Multiple possible formats for pytest summary
+            summary_patterns = [
+                r"=+\s+(.+?)\s+in\s+([\d.]+)s?\s*=+",  # Standard format: "======= 5 passed in 1.23s ======="
+                r"(\d+\s+\w+)+\s+in\s+([\d.]+)s?",     # Alternative format: "5 passed, 2 failed in 1.23s"
+                r"(\d+.*)in\s+([\d.]+)s?"              # More flexible format
+            ]
+
+            match = None
+            for pattern in summary_patterns:
+                match = re.search(pattern, output)
+                if match:
+                    break
+
+            if match:
+                # Determine which groups contain the summary text and duration
+                if len(match.groups()) >= 2:
+                    summary_text = match.group(1)
+                    stats["duration"] = float(match.group(2))
+                else:
+                    # If pattern only captured duration, look for summary in whole match
+                    stats["duration"] = float(match.group(1)) if match.group(1).replace('.', '').isdigit() else 0.0
+                    summary_text = output  # Use entire output to find metrics
+
+                # Extract individual counts
+                for metric in ["passed", "failed", "skipped", "error", "xfailed", "xpassed"]:
+                    metric_pattern = rf"(\d+)\s+{metric}"
+                    metric_match = re.search(metric_pattern, summary_text, re.IGNORECASE)
+                    if metric_match:
+                        count = int(metric_match.group(1))
+                        key = "errors" if metric == "error" else metric
+                        stats[key] = count
+
+                # Calculate total
+                stats["total"] = sum([
+                    stats["passed"],
+                    stats["failed"],
+                    stats["skipped"],
+                    stats["errors"],
+                    stats["xfailed"],
+                    stats["xpassed"],
+                ])
+
+                # If total is still 0, try to manually count from the output
+                if stats["total"] == 0:
+                    # Count different statuses in the output more reliably
+                    stats["passed"] = len(re.findall(r'(?:\.|✓)\s*(?:PASSED|pass)', output, re.IGNORECASE))
+                    stats["failed"] = len(re.findall(r'(?:F|X|❌)\s*(?:FAILED|fail)', output, re.IGNORECASE)) or len(re.findall(r'FAILED', output))
+                    stats["skipped"] = len(re.findall(r'(?:s|S|.SKIPPED|skip)', output, re.IGNORECASE))
+                    stats["errors"] = len(re.findall(r'ERROR|E\s+', output, re.IGNORECASE))
+                    stats["total"] = stats["passed"] + stats["failed"] + stats["skipped"] + stats["errors"]
+
+            # Try to extract coverage if present
+            # Coverage format: "TOTAL    160     32    80%"
+            coverage_pattern = r"TOTAL\s+\d+\s+\d+\s+(\d+)%"
+            coverage_match = re.search(coverage_pattern, output)
+            if coverage_match:
+                stats["coverage"] = float(coverage_match.group(1))
+
+        except (ValueError, AttributeError) as e:
+            # If parsing fails, return empty stats
+            self.console.print(f"[dim]⚠️ Failed to parse test statistics: {e}[/dim]")
+
+        return stats
+
+    def _render_test_results_panel(
+        self,
+        stats: dict[str, t.Any],
+        workers: int | str,
+        success: bool,
+    ) -> None:
+        """Render test results panel with statistics similar to hook results.
+
+        Args:
+            stats: Dictionary of test statistics from _parse_test_statistics
+            workers: Number of workers used (or "auto")
+            success: Whether tests passed overall
+        """
+        table = Table(box=box.SIMPLE, header_style="bold bright_white")
+        table.add_column("Metric", style="cyan", overflow="fold")
+        table.add_column("Count", justify="right", style="bright_white")
+        table.add_column("Percentage", justify="right", style="magenta")
+
+        total = stats["total"]
+
+        # Add rows for each metric
+        metrics = [
+            ("✅ Passed", stats["passed"], "green"),
+            ("❌ Failed", stats["failed"], "red"),
+            ("⏭ Skipped", stats["skipped"], "yellow"),
+            ("💥 Errors", stats["errors"], "red"),
+        ]
+
+        # Only show xfailed/xpassed if they exist
+        if stats.get("xfailed", 0) > 0:
+            metrics.append(("⚠️ Expected Failures", stats["xfailed"], "yellow"))
+        if stats.get("xpassed", 0) > 0:
+            metrics.append(("✨ Unexpected Passes", stats["xpassed"], "green"))
+
+        for label, count, _ in metrics:
+            percentage = f"{(count / total * 100):.1f}%" if total > 0 else "0.0%"
+            table.add_row(label, str(count), percentage)
+
+        # Add separator and summary rows
+        table.add_row("─" * 20, "─" * 10, "─" * 15, style="dim")
+        table.add_row("📊 Total Tests", str(total), "100.0%", style="bold")
+        table.add_row(
+            "⏱ Duration",
+            f"{stats['duration']:.2f}s",
+            "",
+            style="bold magenta",
+        )
+        table.add_row(
+            "👥 Workers",
+            str(workers),
+            "",
+            style="bold cyan",
+        )
+
+        # Add coverage if available
+        if stats.get("coverage") is not None:
+            table.add_row(
+                "📈 Coverage",
+                f"{stats['coverage']:.1f}%",
+                "",
+                style="bold green",
+            )
+
+        # Create panel with appropriate styling
+        border_style = "green" if success else "red"
+        title_icon = "✅" if success else "❌"
+        title_text = "Test Results" if success else "Test Results (Failed)"
+
+        panel = Panel(
+            table,
+            title=f"[bold]{title_icon} {title_text}[/bold]",
+            border_style=border_style,
+            padding=(0, 1),
+            width=get_console_width(),
+        )
+
+        self.console.print(panel)
+
     def _process_coverage_ratchet(self) -> bool:
         if not self.coverage_ratchet_enabled:
             return True
@@ -328,23 +551,29 @@ class TestManager:
     ) -> float | None:
         """Get coverage from fallback sources."""
         # Secondary: Try ratchet result if coverage.json failed
-        if current_coverage is None:
-            current_coverage = self._get_coverage_from_ratchet(ratchet_result)
-            if current_coverage is not None:
-                self.console.print(
-                    f"[dim]📊 Coverage from ratchet result: {current_coverage:.2f}%[/dim]"
-                )
+        if current_coverage is None and ratchet_result:
+            # Try to extract from ratchet result
+            if "current_coverage" in ratchet_result:
+                current_coverage = ratchet_result["current_coverage"]
+                if current_coverage is not None and current_coverage > 0:
+                    self.console.print(
+                        f"[dim]📊 Coverage from ratchet result: {current_coverage:.2f}%[/dim]"
+                    )
 
         # Tertiary: Try coverage service, but only accept non-zero values
         if current_coverage is None:
-            current_coverage = self._get_coverage_from_service()
-            if current_coverage is not None:
-                self.console.print(
-                    f"[dim]📊 Coverage from service fallback: {current_coverage:.2f}%[/dim]"
-                )
+            try:
+                current_coverage = self._get_coverage_from_service()
+                if current_coverage is not None:
+                    self.console.print(
+                        f"[dim]📊 Coverage from service fallback: {current_coverage:.2f}%[/dim]"
+                    )
+            except AttributeError:
+                # Service method doesn't exist, skip
+                pass
             else:
                 coverage_json_path = self.pkg_path / "coverage.json"
-                if coverage_json_path.exists():
+                if current_coverage is None and coverage_json_path.exists():
                     self.console.print(
                         "[yellow]⚠️[/yellow] Skipping 0.0% fallback when coverage.json exists"
                     )
@@ -354,6 +583,19 @@ class TestManager:
     def _update_coverage_badge(self, ratchet_result: dict[str, t.Any]) -> None:
         """Update coverage badge in README.md if coverage changed."""
         try:
+            # Check if coverage files exist and inform user
+            coverage_json_path = self.pkg_path / "coverage.json"
+            ratchet_path = self.pkg_path / ".coverage-ratchet.json"
+
+            if not coverage_json_path.exists():
+                self.console.print(
+                    "[yellow]ℹ️[/yellow] Coverage file doesn't exist yet, will be created after test run"
+                )
+            if not ratchet_path.exists():
+                self.console.print(
+                    "[yellow]ℹ️[/yellow] Coverage ratchet file doesn't exist yet, initializing..."
+                )
+
             # Get current coverage directly from coverage.json to ensure freshest data
             current_coverage = self._attempt_coverage_extraction()
             current_coverage = self._handle_coverage_extraction_result(current_coverage)
@@ -392,12 +634,12 @@ class TestManager:
             return True
         else:
             if "message" in ratchet_result:
-                self.console.print(f"[red]📉[/ red] {ratchet_result['message']}")
+                self.console.print(f"[red]📉[/red] {ratchet_result['message']}")
             else:
                 current = ratchet_result.get("current_coverage", 0)
                 previous = ratchet_result.get("previous_coverage", 0)
                 self.console.print(
-                    f"[red]📉[/ red] Coverage regression: "
+                    f"[red]📉[/red] Coverage regression: "
                     f"{current: .2f}% < {previous: .2f}%"
                 )
             return False
@@ -407,7 +649,7 @@ class TestManager:
         current = ratchet_result.get("current_coverage", 0)
 
         self.console.print(
-            f"[green]📈[/ green] Coverage improved by {improvement: .2f}% "
+            f"[green]📈[/green] Coverage improved by {improvement: .2f}% "
             f"to {current: .2f}%"
         )
 
