@@ -10,7 +10,9 @@ from .config import (
     TestConfig,
     WorkflowOptions,
 )
-from .protocols import OptionsProtocol
+from .protocols import OptionsProtocol, QAAdapterProtocol, QAOrchestratorProtocol
+from .qa_config import QACheckConfig, QAOrchestratorConfig
+from .qa_results import QACheckType, QAResult, QAResultStatus
 from .task import HookResult, SessionTracker, TaskStatus
 
 __all__ = [
@@ -24,6 +26,13 @@ __all__ = [
     "OptionsProtocol",
     "ProgressConfig",
     "PublishConfig",
+    "QAAdapterProtocol",
+    "QACheckConfig",
+    "QACheckType",
+    "QAOrchestratorConfig",
+    "QAOrchestratorProtocol",
+    "QAResult",
+    "QAResultStatus",
     "SessionTracker",
     "TaskStatus",
     "TestConfig",
