@@ -147,6 +147,8 @@ class GitInterface(t.Protocol):
 
     def push(self) -> bool: ...
 
+    def push_with_tags(self) -> bool: ...
+
     def add_files(self, files: list[str]) -> bool: ...
 
     def add_all_files(self) -> bool: ...
@@ -294,6 +296,8 @@ class PublishManager(t.Protocol):
 
     def create_git_tag(self, version: str) -> bool: ...
 
+    def create_git_tag_local(self, version: str) -> bool: ...
+
     def cleanup_old_releases(self, keep_releases: int) -> None: ...
 
 
@@ -756,12 +760,14 @@ class HookOrchestratorProtocol(t.Protocol):
         self,
         strategy: t.Any,  # HookStrategy
         execution_mode: str | None = None,
+        execution_context: t.Any | None = None,
     ) -> list[t.Any]:  # list[HookResult]
         """Execute hook strategy with specified mode.
 
         Args:
             strategy: HookStrategy (fast or comprehensive)
             execution_mode: "legacy" (pre-commit CLI) or "acb" (direct adapters)
+            execution_context: Context containing options and execution environment
 
         Returns:
             List of HookResult objects
