@@ -14,6 +14,7 @@ from __future__ import annotations
 import asyncio
 import logging
 import typing as t
+from contextlib import suppress
 
 from crackerjack.config.hooks import HookDefinition, SecurityLevel
 from crackerjack.models.task import HookResult
@@ -93,6 +94,8 @@ class AdaptiveExecutionStrategy:
         timeout: int | None = None,
         executor_callable: t.Callable[[HookDefinition], t.Awaitable[HookResult]]
         | None = None,
+        progress_callback: t.Callable[[int, int], None] | None = None,
+        progress_start_callback: t.Callable[[int, int], None] | None = None,
     ) -> list[HookResult]:
         """Execute hooks in dependency-aware waves.
 
@@ -101,6 +104,7 @@ class AdaptiveExecutionStrategy:
             max_parallel: Optional override for max concurrent executions per wave
             timeout: Optional override for default timeout
             executor_callable: Async function that executes a single hook
+            progress_callback: Optional callback(completed, total) for progress updates
 
         Returns:
             List of HookResult objects (combined from all waves)
@@ -141,6 +145,13 @@ class AdaptiveExecutionStrategy:
 
         # Execute each wave in parallel, waves sequentially
         all_results = []
+        total_hooks = len(hooks)
+        completed_hooks = 0
+
+        # Initial progress report
+        if progress_callback:
+            progress_callback(0, total_hooks)
+
         for wave_idx, wave_hooks in enumerate(waves, 1):
             logger.info(
                 f"Executing wave {wave_idx}/{len(waves)}",
@@ -153,11 +164,27 @@ class AdaptiveExecutionStrategy:
             )
 
             # Execute this wave in parallel
+            # Define per-hook completion notifier to update progress incrementally
+            def on_hook_start() -> None:
+                nonlocal completed_hooks
+                # Use started count as the metric to tick the progress bar
+                started = completed_hooks + 1
+                if progress_start_callback:
+                    progress_start_callback(started, total_hooks)
+
+            def on_hook_complete() -> None:
+                nonlocal completed_hooks
+                completed_hooks += 1
+                if progress_callback:
+                    progress_callback(completed_hooks, total_hooks)
+
             wave_results = await self._execute_wave(
                 wave_hooks,
                 max_parallel=max_par,
                 timeout=timeout_sec,
                 executor_callable=executor_callable,
+                on_hook_complete=on_hook_complete,
+                on_hook_start=on_hook_start,
             )
 
             all_results.extend(wave_results)
@@ -331,6 +358,8 @@ class AdaptiveExecutionStrategy:
         max_parallel: int,
         timeout: int,
         executor_callable: t.Callable[[HookDefinition], t.Awaitable[HookResult]] | None,
+        on_hook_complete: t.Callable[[], None] | None = None,
+        on_hook_start: t.Callable[[], None] | None = None,
     ) -> list[HookResult]:
         """Execute a single wave of hooks in parallel.
 
@@ -351,6 +380,10 @@ class AdaptiveExecutionStrategy:
         async def execute_with_limit(hook: HookDefinition) -> HookResult:
             """Execute hook with semaphore and timeout."""
             async with semaphore:
+                # Notify start before executing the hook
+                if on_hook_start:
+                    with suppress(Exception):
+                        on_hook_start()
                 try:
                     hook_timeout = hook.timeout or timeout
                     logger.debug(
@@ -382,6 +415,10 @@ class AdaptiveExecutionStrategy:
                             "duration": result.duration,
                         },
                     )
+                    # Notify per-hook completion for progress updates
+                    if on_hook_complete:
+                        with suppress(Exception):
+                            on_hook_complete()
                     return result
 
                 except TimeoutError:
