@@ -6,7 +6,8 @@ import re
 import typing as t
 from pathlib import Path
 
-from rich.console import Console
+from acb.console import Console
+from acb.depends import Inject, depends
 
 from ..models.protocols import APIExtractorProtocol
 from .regex_patterns import SAFE_PATTERNS
@@ -120,7 +121,8 @@ class PythonDocstringParser:
 class APIExtractorImpl(APIExtractorProtocol):
     """Implementation of API documentation extraction from source code."""
 
-    def __init__(self, console: Console) -> None:
+    @depends.inject
+    def __init__(self, console: Inject[Console]) -> None:
         self.console = console
         self.docstring_parser = PythonDocstringParser()
 
