@@ -357,8 +357,7 @@ class DependencyMonitorService:
 
         cached_data = cache[cache_key]
         cache_age = current_time - cached_data["timestamp"]
-        is_fresh: bool = cache_age < 86400
-        return is_fresh
+        return cache_age < 86400
 
     def _create_major_update_from_cache(
         self,
@@ -452,13 +451,13 @@ class DependencyMonitorService:
 
         import requests
 
-        url = f"https://pypi.org/pypi/{package}/json"
+        url = f"https: //pypi.org/pypi/{package}/json"
         self._validate_pypi_url(url)
 
         parsed = urlparse(url)
 
         if parsed.scheme != "https" or parsed.netloc != "pypi.org":
-            msg = f"Invalid URL: only https://pypi.org URLs are allowed, got {url}"
+            msg = f"Invalid URL: only https: //pypi.org URLs are allowed, got {url}"
             raise ValueError(msg)
 
         response = requests.get(url, timeout=10, verify=True)
@@ -502,8 +501,7 @@ class DependencyMonitorService:
     def _get_release_date(self, releases: dict[str, t.Any], version: str) -> str:
         release_info = releases.get(version, [])
         if release_info:
-            upload_time: str = release_info[0].get("upload_time", "")
-            return upload_time
+            return release_info[0].get("upload_time", "")
         return ""
 
     def _has_breaking_changes(self, version: str) -> bool:
