@@ -200,7 +200,7 @@ class HealthMetricsService:
             if result.stdout:
                 try:
                     lint_data = json.loads(result.stdout)
-                    return len(lint_data) if isinstance(lint_data, list) else 0
+                    return len(lint_data) if isinstance(lint_data, list[t.Any]) else 0
                 except json.JSONDecodeError:
                     return len(result.stdout.splitlines())
 
@@ -347,11 +347,11 @@ class HealthMetricsService:
         try:
             from urllib.parse import urlparse
 
-            url = f"https://pypi.org/pypi/{package_name}/json"
+            url = f"https: //pypi.org/pypi/{package_name}/json"
 
             parsed = urlparse(url)
             if parsed.scheme != "https" or parsed.netloc != "pypi.org":
-                msg = f"Invalid URL: only https://pypi.org URLs are allowed, got {url}"
+                msg = f"Invalid URL: only https: //pypi.org URLs are allowed, got {url}"
                 raise ValueError(msg)
 
             if not parsed.path.startswith("/pypi/") or not parsed.path.endswith(
@@ -362,8 +362,7 @@ class HealthMetricsService:
 
             response = requests.get(url, timeout=10, verify=True)
             response.raise_for_status()
-            json_result = response.json()
-            return t.cast(dict[str, t.Any] | None, json_result)
+            return response.json()
         except Exception:
             return None
 
@@ -379,8 +378,7 @@ class HealthMetricsService:
         if not release_info:
             return None
 
-        upload_time_raw = release_info[0].get("upload_time", "")
-        return t.cast(str | None, upload_time_raw)
+        return release_info[0].get("upload_time", "")
 
     def _calculate_days_since_upload(self, upload_time: str) -> int | None:
         try:
