@@ -156,9 +156,13 @@ class WorkflowContainerBuilder:
         These are the foundation services with no dependencies (except Config
         which uses the current directory by default).
         """
-        # Console
+        # Console - Configure width from settings for progress bars
         if not self._console:
             self._console = Console()
+            # Set console width from configuration
+            from crackerjack.config import get_console_width
+
+            self._console.width = get_console_width()
         depends.set(Console, self._console)
         self._registered.add("Console")
 
@@ -350,6 +354,13 @@ class WorkflowContainerBuilder:
         # Level 4.5: Register TestManager dependencies
         self._register_level4_5_test_manager_dependencies()
 
+        # TestCommandBuilder - needed by TestManager
+        from crackerjack.managers.test_command_builder import TestCommandBuilder
+
+        test_command_builder = TestCommandBuilder()
+        depends.set(TestCommandBuilder, test_command_builder)
+        self._registered.add("TestCommandBuilder")
+
         # TestManager - uses @depends.inject (all Level 4.5 dependencies registered)
         from crackerjack.managers.test_manager import TestManager
         from crackerjack.models.protocols import TestManagerProtocol
